ModelMap

Struct ModelMap 

pub struct ModelMap<Inner: FitModel, Map: DifferentiableFunction<Inner::Scalar>> {
    pub inner: Inner,
    /* private fields */
}
Model equal to application of a function on top of a model.

You can’t construct this struct manually, please use model_map for that. This is motivated by it’s fields containing two separate objects (value and derivative), that are actually dependent and should be derived from each other.

Fields

inner: Inner

Inner model.