FitStat

Struct FitStat 

pub struct FitStat<Model: FitModelErrors + LevMarModel> {
    pub report: MinimizationReport<Model::Scalar>,
    pub reduced_chi2: Model::Scalar,
    pub errors: Model::OwnedModel,
    pub covariance_matrix: GenericMatrix<Model::Scalar, Model::ParamCount, Model::ParamCount>,
}
Result of fit_stat.

Fields

report: MinimizationReport<Model::Scalar>

Report resulted from the fit

reduced_chi2: Model::Scalar

$\chi^{2}/\test{dof}$ criteria. Should be about 1 for correct fit.

errors: Model::OwnedModel

Type defined by model, containing parameter errors.

This will usually be the model type itself, but there may be exceptions.

covariance_matrix: GenericMatrix<Model::Scalar, Model::ParamCount, Model::ParamCount>

A parameter covariance matrix. If you don’t know what this is, you can safely ignore it.